@@ -1,7 +1,7 @@
 import os
 from flask import Flask
 from flask.ext.sqlalchemy import SQLAlchemy
-from flask import request, send_from_directory
+from flask import request, send_from_directory, render_template
 from flask import make_response, redirect
 import requests
 import json
@@ -16,7 +16,7 @@ import databases
 import random
 import hashlib
 
-app = Flask(__name__, static_url_path='')
+app = Flask(__name__, static_url_path='', template_folder="static/explorer")
 app.config['PROPAGATE_EXCEPTIONS']=True
 dbname='barisser'
 app.config['SQLALCHEMY_DATABASE_URI'] = os.environ['DATABASE_URL']  #"postgresql://localhost/"+dbname
@@ -38,6 +38,19 @@ def whitepaper():
 def quickstart():
   return app.send_static_file('quickstart/index.html')
 
+@app.route('/addresses/<address>', methods=['GET'])
+def gotoaddressexplorer(address=None):
+  return render_template('addresses.html', the_address=address)
+
+@app.route('/colors/<color>', methods=['GET'])
+def gotocolorexplorer(color=None):
+  return render_template('colors.html', the_color=color)
+
+
+
+
+
+
 
 @app.route('/v1/blocks/count')
 def getblockcount():
@@ -117,6 +130,14 @@ def colorbalances(public_address=None):
   jsonresponse['assets']=[]
   for x in answer:
     r={}
+    colorname=databases.dbexecute("select color_name from colors where color_address='"+str(x)+"';", True)
+    if len(colorname)>0:
+      colorname=colorname[0][0]
+      if colorname=="color_name":
+        colorname=""
+    else:
+      colorname=""
+    r['color_name']=colorname
     r['color_address']=x
     r['quantity']=answer[x]
     jsonresponse['assets'].append(r)
@@ -203,10 +224,25 @@ def colorholders(color_address=None):
   answer=databases.color_holders(color_address)
   if len(answer)==0:
     color_address=databases.first_coloraddress_from_sourceaddress(color_address)
-    answer=databases.color_holders(color_address)
+    if not color_address is None:
+      answer=databases.color_holders(color_address)
+    else:
+      answer=""
+
+  colordata=databases.dbexecute("select * from colors where color_address='"+color_address+"';",True)
+  source_address="not found"
+  color_name="not found"
+  if len(colordata)>0:
+    source_address=colordata[0][1]
+    color_name=colordata[0][3]
+    if color_name=="color_name":
+      color_name=""
+
   jsonresponse={}
   jsonresponse['owners']=[]
   jsonresponse['color_address']=color_address
+  jsonresponse['issuing_address']=source_address
+  jsonresponse['color_name']=color_name
   for x in answer:
     r={}
     r['public_address']=x
@@ -410,7 +446,7 @@ def schedule_transfer():
   fee_each=float(jsoninput['fee_each'])
   fee_each=str(int(fee_each*100000000))
   privatekey=str(jsoninput['from_private_key'])
-  sourceaddress=str(jsoninput['source_address'])
+  sourceaddress=str(jsoninput['issuing_address'])
   coloramt=str(jsoninput['transfer_amount'])
 
   r=str(random.random())
@@ -440,7 +476,7 @@ def transfer_many_serverside():
   dest_array=jsoninput['destinations']
   fee_each=float(jsoninput['fee_each'])
   privatekey=str(jsoninput['from_private_key'])
-  sourceaddress=str(jsoninput['source_address'])
+  sourceaddress=str(jsoninput['issuing_address'])
   coloramt_array=jsoninput['transfer_amounts']
   results=transactions.multiple_transfer_txs(fromaddr, dest_array, fee_each, privatekey, sourceaddress, coloramt_array)
   jsonresponse={}
