@@ -17,7 +17,7 @@ def getblock_blockchain(blockn):
     return answer
   except:
     print "COULD NOT GET BLOCK FROM BLOCKCHAIN.info"
-    return {}
+
 
 def getblock_toshi(blockn):
   try:
@@ -88,7 +88,7 @@ def output_db(blockn):
 
           #EDIT COLOR OVERVIEW DATA
         oldamount=databases.read_color(coloraddress)
-        if len(oldamount)==0:
+        if len(oldamount)==0:  #COLOR DOES NOT EXIST YET
           source_address=prev_input[7:len(prev_input)]
           databases.add_color(coloraddress, source_address, coloramt, "color_name")
         else:
@@ -276,22 +276,48 @@ def blocks_outputs(blockend):
     databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
 
 def more_blocks(moreblocks):
-    currentblock=bitsource.get_current_block()
+    currentblock=int(bitsource.get_current_block())
     lastblockprocessed=databases.dbexecute("SELECT * FROM META;",True)
     nextblock=lastblockprocessed[0][0]+moreblocks
+
+    print "starting block " +str(currentblock)
+    print "nextblock "+str(nextblock)
+
     if nextblock>currentblock:
       nextblock=currentblock
+
+    if lastblockprocessed[0][0]<currentblock:
       for i in range(lastblockprocessed[0][0]+1, nextblock+1):
         if i<=currentblock:
-          output_db(i)
-          print "processed block "+str(i)
-          databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
+          try:
+            output_db(i)
+            print "processed block "+str(i)
+            databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
+          except:
+            print "could not update block"
 
-    elif nextblock<=currentblock:
-      for i in range(lastblockprocessed[0][0]+1, nextblock+1):
-        output_db(i)
-        print "processed block "+str(i)
-        databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
+    #
+    # if nextblock>currentblock and lastblockprocessed<currentblock:
+    #   nextblock=currentblock
+    #   for i in range(lastblockprocessed[0][0]+1, nextblock+1):
+    #
+    #     if i<=currentblock:
+    #       try:
+    #         output_db(i)
+    #         print "processed block "+str(i)
+    #         databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
+    #       except:
+    #         print "could not update block"
+    #
+    # elif nextblock<currentblock:
+    #   for i in range(lastblockprocessed[0][0]+1, nextblock+1):
+    #     if i<=currentblock:
+    #       try:
+    #         output_db(i)
+    #         print "processed block "+str(i)
+    #         databases.dbexecute("UPDATE META SET lastblockdone='"+str(i)+"';",False)
+    #       except:
+    #         print "could not update block"
 
 def checkaddresses():
   dbstring="SELECT * FROM ADDRESSES WHERE amount_withdrawn=0;"
@@ -326,7 +352,8 @@ def checkaddresses():
       #add entry to colors db
       # #referencehex=bitsource.tx_lookup(specific_inputs)
       # color_address=bitsource.script_to_coloraddress()
-      # databases.add_color(color_address, fromaddr, colornumber, colorname)
+      #databases.add_color(color_address, fromaddr, colornumber, colorname)
+      databases.dbexecute("insert into colors (source_address, color_name) values ('"+fromaddr+"','"+colorname+"');",False)
 
       #add entry to outputs db
 
@@ -356,3 +383,17 @@ def verify_colors():
     dbstring="update outputs set color_address='"+coloraddress+"' where txhash_index='"+unknown[7]+"';"
     print dbstring
     databases.dbexecute(dbstring,False)
+
+def read_color_names():
+  unnamed_colors=databases.dbexecute("select * from colors where color_name='color_name';",True)
+  for unnamed_color in unnamed_colors:
+    #lookup metadata on blockchain
+    address=unnamed_color[1] #the source_address
+    result=addresses.read_opreturns_sent_by_address(address)
+    name="color_name"
+    try:
+      name=json.loads(result)
+      name=name['name']
+      databases.dbexecute("update colors set color_name='"+name+"' where source_address='"+address+"';", False)
+    except:
+      print "no name found for source: "+str(address)
